@@ -1,6 +1,3 @@
-
-from __future__ import print_function
-
 __doc__ = """GNUmed client internationalization/localization.
 
 All i18n/l10n issues should be handled through this modules.
@@ -63,33 +60,28 @@ import locale
 import gettext
 import logging
 import codecs
+import builtins
 import re as regex
 
+
+builtins._ = lambda x:x
+
 _log = logging.getLogger('gm.i18n')
 
 system_locale = ''
 system_locale_level = {}
 
-
-_translate_original = lambda x:x
+_translate_via_gettext = lambda x:x
 _substitutes_regex = regex.compile(r'%\(.+?\)s')
 
-# **********************************************************
-# == do not remove this line ===============================
-# it is needed to check for successful installation of
-# the desired message catalog
-# **********************************************************
-__orig_tag__ = u'Translate this or i18n into <en_EN> will not work properly !'
-# **********************************************************
-# **********************************************************
-
-# Q: I can't use non-ascii characters in labels and menus.
-# A: This can happen if your Python's system encoding is ASCII and
-#    wxPython is non-unicode. Edit/create the file sitecustomize.py
-#    (should be somewhere in your PYTHONPATH), and put these magic lines:
-#
-#	import sys
-#	sys.setdefaultencoding('iso8859-1') # replace with encoding you want to be the default one
+# ***************************************************************************
+# ***************************************************************************
+# The following line is needed to check for successful
+# installation of the desired message catalog.
+# -- do not remove or change this line --------------------------------------
+__orig_tag__ = 'Translate this or i18n into <en_EN> will not work properly !'
+# ***************************************************************************
+# ***************************************************************************
 
 #===========================================================================
 def __split_locale_into_levels():
@@ -115,37 +107,33 @@ def __split_locale_into_levels():
 #---------------------------------------------------------------------------
 def __log_locale_settings(message=None):
 	_setlocale_categories = {}
-	for category in 'LC_ALL LC_CTYPE LC_COLLATE LC_TIME LC_MONETARY LC_MESSAGES LC_NUMERIC'.split():
+	for category in 'LC_ALL LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT LC_IDENTIFICATION'.split():
 		try:
 			_setlocale_categories[category] = getattr(locale, category)
-		except:
+		except Exception:
 			_log.warning('this OS does not have locale.%s', category)
-
 	_getlocale_categories = {}
-	for category in 'LC_CTYPE LC_COLLATE LC_TIME LC_MONETARY LC_MESSAGES LC_NUMERIC'.split():
+	for category in 'LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT LC_IDENTIFICATION'.split():
 		try:
 			_getlocale_categories[category] = getattr(locale, category)
-		except:
+		except Exception:
 			pass
-
 	if message is not None:
 		_log.debug(message)
 
 	_log.debug('current locale settings:')
 	_log.debug('locale.getlocale(): %s' % str(locale.getlocale()))
-	for category in _getlocale_categories.keys():
+	for category in _getlocale_categories:
 		_log.debug('locale.getlocale(%s): %s' % (category, locale.getlocale(_getlocale_categories[category])))
-
-	for category in _setlocale_categories.keys():
+	for category in _setlocale_categories:
 		_log.debug('(locale.setlocale(%s): %s)' % (category, locale.setlocale(_setlocale_categories[category])))
-
 	try:
 		_log.debug('locale.getdefaultlocale() - default (user) locale: %s' % str(locale.getdefaultlocale()))
 	except ValueError:
 		_log.exception('the OS locale setup seems faulty')
 
 	_log.debug('encoding sanity check (also check "locale.nl_langinfo(CODESET)" below):')
-	pref_loc_enc = locale.getpreferredencoding(do_setlocale=False)
+	pref_loc_enc = locale.getpreferredencoding(do_setlocale = False)
 	loc_enc = locale.getlocale()[1]
 	py_str_enc = sys.getdefaultencoding()
 	sys_fs_enc = sys.getfilesystemencoding()
@@ -155,10 +143,10 @@ def __log_locale_settings(message=None):
 	_log.debug('sys.getfilesystemencoding(): [%s]' % sys_fs_enc)
 	if loc_enc is not None:
 		loc_enc = loc_enc.upper()
-		loc_enc_compare = loc_enc.replace(u'-', u'')
+		loc_enc_compare = loc_enc.replace('-', '')
 	else:
 		loc_enc_compare = loc_enc
-	if pref_loc_enc.upper().replace(u'-', u'') != loc_enc_compare:
+	if pref_loc_enc.upper().replace('-', '') != loc_enc_compare:
 		_log.warning('encoding suggested by locale (%s) does not match encoding currently set in locale (%s)' % (pref_loc_enc, loc_enc))
 		_log.warning('this might lead to encoding errors')
 	for enc in [pref_loc_enc, loc_enc, py_str_enc, sys_fs_enc]:
@@ -179,45 +167,44 @@ def __log_locale_settings(message=None):
 
 	_log.debug('database of locale conventions:')
 	data = locale.localeconv()
-	for key in data.keys():
+	for key in data:
 		if loc_enc is None:
-			_log.debug(u'locale.localeconv(%s): %s', key, data[key])
+			_log.debug('locale.localeconv(%s): %s', key, data[key])
 		else:
 			try:
-				_log.debug(u'locale.localeconv(%s): %s', key, unicode(data[key]))
+				_log.debug('locale.localeconv(%s): %s', key, str(data[key]))
 			except UnicodeDecodeError:
-				_log.debug(u'locale.localeconv(%s): %s', key, unicode(data[key], loc_enc))
+				_log.debug('locale.localeconv(%s): %s', key, str(data[key], loc_enc))
 	_nl_langinfo_categories = {}
 	for category in 'CODESET D_T_FMT D_FMT T_FMT T_FMT_AMPM RADIXCHAR THOUSEP YESEXPR NOEXPR CRNCYSTR ERA ERA_D_T_FMT ERA_D_FMT ALT_DIGITS'.split():
 		try:
 			_nl_langinfo_categories[category] = getattr(locale, category)
-		except:
+		except Exception:
 			_log.warning('this OS does not support nl_langinfo category locale.%s' % category)
 	try:
-		for category in _nl_langinfo_categories.keys():
+		for category in _nl_langinfo_categories:
 			if loc_enc is None:
 				_log.debug('locale.nl_langinfo(%s): %s' % (category, locale.nl_langinfo(_nl_langinfo_categories[category])))
 			else:
 				try:
-					_log.debug(u'locale.nl_langinfo(%s): %s', category, unicode(locale.nl_langinfo(_nl_langinfo_categories[category])))
+					_log.debug('locale.nl_langinfo(%s): %s', category, str(locale.nl_langinfo(_nl_langinfo_categories[category])))
 				except UnicodeDecodeError:
-					_log.debug(u'locale.nl_langinfo(%s): %s', category, unicode(locale.nl_langinfo(_nl_langinfo_categories[category]), loc_enc))
-	except:
+					_log.debug('locale.nl_langinfo(%s): %s', category, str(locale.nl_langinfo(_nl_langinfo_categories[category]), loc_enc))
+	except Exception:
 		_log.exception('this OS does not support nl_langinfo')
 
 	_log.debug('gmI18N.get_encoding(): %s', get_encoding())
 
 #---------------------------------------------------------------------------
-#def _translate_protected(term, strip_left=None, strip_right=None):
-def _translate_protected(term):
+def _translate_safely(term):
 	"""This wraps _().
 
 	It protects against translation errors such as a different number of "%s".
 	"""
-	translation = _translate_original(term)
+	translation = _translate_via_gettext(term)
 
 	# different number of %s substitutes ?
-	if translation.count(u'%s') != term.count(u'%s'):
+	if translation.count('%s') != term.count('%s'):
 		_log.error('count("%s") mismatch, returning untranslated string')
 		_log.error('original   : %s', term)
 		_log.error('translation: %s', translation)
@@ -232,12 +219,6 @@ def _translate_protected(term):
 		_log.error('translation: %s', translation)
 		return term
 
-#	if strip_left is not None:
-#		translation = translation.lstrip(strip_left)
-#
-#	if strip_right is not None:
-#		translation = translation.rstrip(strip_right)
-
 	return translation
 
 #---------------------------------------------------------------------------
@@ -246,37 +227,25 @@ def _translate_protected(term):
 def activate_locale():
 	"""Get system locale from environment."""
 	global system_locale
-
-	__log_locale_settings('unmodified startup locale settings (should be [C])')
-
-	# activate user-preferred locale
+	__log_locale_settings('unmodified startup locale settings (could be [C])')
 	loc, enc = None, None
+	# activate user-preferred locale
 	try:
-		# check whether already set
-		loc, loc_enc = locale.getlocale()
-		if loc is None:
-			loc = locale.setlocale(locale.LC_ALL, '')
-			_log.debug("activating user-default locale with <locale.setlocale(locale.LC_ALL, '')> returns: [%s]" % loc)
-		else:
-			_log.info('user-default locale already activated')
-		loc, loc_enc = locale.getlocale()
+		loc = locale.setlocale(locale.LC_ALL, '')
+		_log.debug("activating user-default locale with <locale.setlocale(locale.LC_ALL, '')> returns: [%s]" % loc)
 	except AttributeError:
 		_log.exception('Windows does not support locale.LC_ALL')
-	except:
+	except Exception:
 		_log.exception('error activating user-default locale')
-
 	__log_locale_settings('locale settings after activating user-default locale')
-
-	# did we find any locale setting ? assume en_EN if not
+	# assume en_EN if we did not find any locale settings
 	if loc in [None, 'C']:
 		_log.error('the current system locale is still [None] or [C], assuming [en_EN]')
 		system_locale = "en_EN"
 	else:
 		system_locale = loc
-
 	# generate system locale levels
 	__split_locale_into_levels()
-
 	return True
 
 #---------------------------------------------------------------------------
@@ -289,10 +258,8 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 		# get text domain from name of script
 		domain = os.path.splitext(os.path.basename(sys.argv[0]))[0]
 	_log.info('text domain is [%s]' % domain)
-
 	# http://www.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap08.html
 	_log.debug('searching message catalog file for system locale [%s]' % system_locale)
-
 	_log.debug('checking process environment:')
 	for env_var in ['LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG']:
 		tmp = os.getenv(env_var)
@@ -300,7 +267,6 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 			_log.debug(' ${%s} not set' % env_var)
 		else:
 			_log.debug(' ${%s} = [%s]' % (env_var, tmp))
-
 	# language codes to try
 	lang_candidates = []
 	# first: explicit language or default system language
@@ -311,35 +277,30 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 		_log.info('explicit request for target language [%s]' % language)
 		# next: try default language for user if explicit language fails
 		lang_candidates.append(None)
-
 	# next try locale.getlocale()[0], if different (this can be strange on, say, Windows: Hungarian_Hungary)
 	if locale.getlocale()[0] not in lang_candidates:
 		lang_candidates.append(locale.getlocale()[0])
-
 	# next try locale.get*default*locale()[0], if different
 	if locale.getdefaultlocale()[0] not in lang_candidates:
 		lang_candidates.append(locale.getdefaultlocale()[0])
-
 	_log.debug('languages to try for translation: %s (None: implicit system default)', lang_candidates)
 	initial_lang = os.getenv('LANG')
 	_log.info('initial ${LANG} setting: %s', initial_lang)
-
 	# loop over language candidates
 	for lang_candidate in lang_candidates:
 		# setup baseline
 		_log.debug('resetting ${LANG} to initial user default [%s]', initial_lang)
 		if initial_lang is None:
 			del os.environ['LANG']
-			lang2log = u'$LANG=<>'
+			lang2log = '$LANG=<>'
 		else:
 			os.environ['LANG'] = initial_lang
-			lang2log = u'$LANG(default)=%s' % initial_lang
+			lang2log = '$LANG(default)=%s' % initial_lang
 		# setup candidate language
 		if lang_candidate is not None:
 			_log.info('explicitely overriding system locale language [%s] by setting ${LANG} to [%s]', initial_lang, lang_candidate)
 			os.environ['LANG'] = lang_candidate
-			lang2log = u'$LANG(explicit)=%s' % lang_candidate
-
+			lang2log = '$LANG(explicit)=%s' % lang_candidate
 		if __install_domain(domain = domain, prefer_local_catalog = prefer_local_catalog, language = lang2log):
 			return True
 
@@ -351,12 +312,11 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 	return True
 
 #---------------------------------------------------------------------------
-def __install_domain(domain, prefer_local_catalog, language=u'?'):
+def __install_domain(domain, prefer_local_catalog, language='?'):
 	# <language> only used for logging
 
 	# search for message catalog
 	candidate_PO_dirs = []
-
 	# - locally
 	if prefer_local_catalog:
 		_log.debug('prioritizing local message catalog')
@@ -371,7 +331,6 @@ def __install_domain(domain, prefer_local_catalog, language=u'?'):
 		loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), 'po'))
 		_log.debug('looking in binary install directory: %s', loc_dir)
 		candidate_PO_dirs.append(loc_dir)
-
 	# - standard places
 	if os.name == 'posix':
 		_log.debug('system is POSIX, looking in standard locations (see Python Manual)')
@@ -380,7 +339,6 @@ def __install_domain(domain, prefer_local_catalog, language=u'?'):
 		candidate_PO_dirs.append(gettext.bindtextdomain(domain))
 	else:
 		_log.debug('No use looking in standard POSIX locations - not a POSIX system.')
-
 	# - $(<script-name>_DIR)/
 	env_key = "%s_DIR" % os.path.splitext(os.path.basename(sys.argv[0]))[0].upper()
 	_log.debug('looking at ${%s}' % env_key)
@@ -390,7 +348,6 @@ def __install_domain(domain, prefer_local_catalog, language=u'?'):
 		candidate_PO_dirs.append(loc_dir)
 	else:
 		_log.info("${%s} not set" % env_key)
-
 	# - locally
 	if not prefer_local_catalog:
 		# - one level above path to binary
@@ -404,7 +361,6 @@ def __install_domain(domain, prefer_local_catalog, language=u'?'):
 		loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), 'po' ))
 		_log.debug('looking in binary install directory [%s]' % loc_dir)
 		candidate_PO_dirs.append(loc_dir)
-
 	# now try to actually install it
 	for candidate_PO_dir in candidate_PO_dirs:
 		_log.debug('trying with (base=%s, %s, domain=%s)', candidate_PO_dir, language, domain)
@@ -412,8 +368,8 @@ def __install_domain(domain, prefer_local_catalog, language=u'?'):
 		if not os.path.exists(candidate_PO_dir):
 			continue
 		try:
-			gettext.install(domain, candidate_PO_dir, unicode = 1)
-		except:
+			gettext.install(domain, candidate_PO_dir)
+		except Exception:
 			_log.exception('installing text domain [%s] failed from [%s]', domain, candidate_PO_dir)
 			continue
 		global _
@@ -421,13 +377,11 @@ def __install_domain(domain, prefer_local_catalog, language=u'?'):
 		if _(__orig_tag__) == __orig_tag__:
 			_log.debug('does not translate: [%s] => [%s]', __orig_tag__, _(__orig_tag__))
 			continue
-		else:
-			_log.debug('found msg catalog: [%s] => [%s]', __orig_tag__, _(__orig_tag__))
-			import __builtin__
-			global _translate_original
-			_translate_original = __builtin__._
-			__builtin__._ = _translate_protected
-			return True
+		_log.debug('found msg catalog: [%s] => [%s]', __orig_tag__, _(__orig_tag__))
+		global _translate_via_gettext
+		_translate_via_gettext = builtins._
+		builtins._ = _translate_safely
+		return True
 
 	return False
 
@@ -484,7 +438,7 @@ if __name__ == "__main__":
 	if len(sys.argv) == 1:
 		sys.exit()
 
-	if sys.argv[1] != u'test':
+	if sys.argv[1] != 'test':
 		sys.exit()
 
 	logging.basicConfig(level = logging.DEBUG)
@@ -497,18 +451,18 @@ if __name__ == "__main__":
 #			(u'1', u'2'),
 #			(u'A', u'A'),
 #			(u'a', u'A'),
-			(u'\u270d', u'\u270d'),
-			(u'4', u'\u270d' + u'4'),
-			(u'4.4', u'\u270d' + u'4.4'),
-			(u'44', u'\u270d' + u'44'),
-			(u'4', u'\u270d' + u'9'),
-			(u'4', u'\u270d' + u'2'),
+			('\u270d', '\u270d'),
+			('4', '\u270d' + '4'),
+			('4.4', '\u270d' + '4.4'),
+			('44', '\u270d' + '44'),
+			('4', '\u270d' + '9'),
+			('4', '\u270d' + '2'),
 #			(u'9', u'\u270d' + u'9'),
 #			(u'9', u'\u270d' + u'4'),
 
 		]
 		for cands in candidates:
-			print(cands[0], u'<vs>', cands[1], '=', locale.strcoll(cands[0], cands[1]))
+			print(cands[0], '<vs>', cands[1], '=', locale.strcoll(cands[0], cands[1]))
 #			print(cands[1], u'<vs>', cands[0], '=', locale.strcoll(cands[1], cands[0]))
 
 	#----------------------------------------------------------------------
