@@ -1,6 +1,3 @@
-
-from __future__ import print_function
-
 __doc__ = """GNUmed general tools."""
 
 #===========================================================================
@@ -15,7 +12,6 @@ import logging
 import subprocess
 import shlex
 
-
 _log = logging.getLogger('gm.shell')
 
 #===========================================================================
@@ -24,23 +20,25 @@ def is_cmd_in_path(cmd=None):
 	_log.debug('cmd: [%s]', cmd)
 	dirname = os.path.dirname(cmd)
 	_log.debug('dir: [%s]', dirname)
-	if dirname != u'':
+	if dirname != '':
 		_log.info('command with full or relative path, not searching in PATH for binary')
 		return (None, None)
 
-	env_paths = unicode(os.environ['PATH'], encoding = sys.getfilesystemencoding(), errors = 'replace')
-	_log.debug(u'${PATH}: %s', env_paths)
+	#env_paths = str(os.environ['PATH'], encoding = sys.getfilesystemencoding(), errors = 'replace')
+	env_paths = os.environ['PATH']
+	_log.debug('${PATH}: %s', env_paths)
 	for path in env_paths.split(os.pathsep):
 		candidate = os.path.join(path, cmd)
 		if os.access(candidate, os.X_OK):
-			_log.debug(u'found [%s]', candidate)
+			_log.debug('found [%s]', candidate)
 			return (True, candidate)
 		else:
-			_log.debug(u'not found: %s', candidate)
+			_log.debug('not found: %s', candidate)
 
-	_log.debug(u'command not found in PATH')
+	_log.debug('command not found in PATH')
 
 	return (False, None)
+
 #===========================================================================
 def is_executable_by_wine(cmd=None):
 
@@ -94,6 +92,7 @@ def is_executable_by_wine(cmd=None):
 
 	_log.warning('Windows path [%s] not verifiable under UNIX: %s', exe_path, full_path)
 	return (False, None)
+
 #===========================================================================
 def detect_external_binary(binary=None):
 	"""<binary> is the name of the executable with or without .exe/.bat"""
@@ -205,10 +204,9 @@ def run_command_in_shell(command=None, blocking=False, acceptable_return_codes=N
 		# - all this, of course, only works in shells which support
 		#   detaching jobs with " &" (so, most POSIX shells)
 		if blocking is True:
-			if command[-2:] == ' &':
-				command = command[:-2]
+			command = command.rstrip(' &')
 		elif blocking is False:
-			if command[-2:] != ' &':
+			if not command.strip().endswith('&'):
 				command += ' &'
 
 	_log.info('running shell command >>>%s<<<', command)
@@ -244,6 +242,7 @@ def run_command_in_shell(command=None, blocking=False, acceptable_return_codes=N
 			_log.debug('platform does not support os.WTERMSIG()')
 
 	return exited_normally
+
 #===========================================================================
 def run_first_available_in_shell(binaries=None, args=None, blocking=False, run_last_one_anyway=False, acceptable_return_codes=None):
 
@@ -258,6 +257,60 @@ def run_first_available_in_shell(binaries=None, args=None, blocking=False, run_l
 			return False
 
 	return run_command_in_shell(command = '%s %s' % (binary, args), blocking = blocking, acceptable_return_codes = acceptable_return_codes)
+
+#===========================================================================
+def _log_output(level, stdout=None, stderr=None):
+	lines2log = ['process output:']
+	if stdout is not None:
+		lines2log.extend([ ' STDOUT: %s' % line for line in stdout.split('\n') ])
+	if stderr is not None:
+		lines2log.extend([ ' STDERR: %s' % line for line in stderr.split('\n') ])
+	_log.log(level, '\n'.join(lines2log))
+
+#===========================================================================
+def run_process(cmd_line=None, timeout=None, encoding='utf8', input_data=None, acceptable_return_codes=None, verbose=False):
+	assert (cmd_line is not None), '<cmd_line> must not be None'
+
+	if acceptable_return_codes is None:
+		acceptable_return_codes = [0]
+	_log.info('running: %s' % cmd_line)
+	try:
+		if input_data is None:
+			proc_result = subprocess.run (
+				args = cmd_line,
+				stdin = subprocess.PIPE,
+				stdout = subprocess.PIPE,
+				stderr = subprocess.PIPE,
+				timeout = timeout,
+				encoding = encoding,
+				errors = 'replace'
+			)
+		else:
+			proc_result = subprocess.run (
+				args = cmd_line,
+				input = input_data,
+				stdout = subprocess.PIPE,
+				stderr = subprocess.PIPE,
+				timeout = timeout,
+				encoding = encoding,
+				errors = 'replace'
+			)
+	except (subprocess.TimeoutExpired, FileNotFoundError):
+		_log.exception('there was a problem running external process')
+		return False, -1, ''
+
+	_log.info('exit code [%s]', proc_result.returncode)
+	if verbose:
+		_log_output(logging.DEBUG, stdout = proc_result.stdout, stderr = proc_result.stderr)
+	if proc_result.returncode not in acceptable_return_codes:
+		_log.error('there was a problem executing the external process')
+		_log.debug('expected one of: %s', acceptable_return_codes)
+		if not verbose:
+			_log_output(logging.ERROR, stdout = proc_result.stdout, stderr = proc_result.stderr)
+		return False, proc_result.returncode, ''
+
+	return True, proc_result.returncode, proc_result.stdout
+
 #===========================================================================
 # main
 #---------------------------------------------------------------------------
@@ -266,7 +319,7 @@ if __name__ == '__main__':
 	if len(sys.argv) < 2:
 		sys.exit()
 
-	if sys.argv[1] != u'test':
+	if sys.argv[1] != 'test':
 		sys.exit()
 
 	logging.basicConfig(level = logging.DEBUG)
@@ -294,9 +347,9 @@ if __name__ == '__main__':
 	def test_is_executable_by_wine():
 		print(is_executable_by_wine(cmd = sys.argv[2]))
 	#---------------------------------------------------------
-	test_run_command_in_shell()
+	#test_run_command_in_shell()
 	#test_detect_external_binary()
-	#test_is_cmd_in_path()
+	test_is_cmd_in_path()
 	#test_is_executable_by_wine()
 
 #===========================================================================
